.. _github-stats-3-2-2:

GitHub Stats for Matplotlib 3.2.2
=================================

GitHub stats for 2020/03/18 - 2020/06/17 (tag: v3.2.1)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 34 issues and merged 92 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/52?closed=1>`__

The following 19 authors contributed 183 commits.

* Antony Lee
* Ben Root
* Clemens Brunner
* David Stansby
* Elliott Sales de Andrade
* Eric Firing
* Eric Wieser
* hannah
* Jody Klymak
* Lawrence D'Anna
* Leo Singer
* Luke Davis
* Matt Newville
* Max
* Ryan May
* Sidharth Bansal
* Stefan Mitic
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (92):

* :ghpull:`17655`: Auto backport of pr 17564 on v3.2.x
* :ghpull:`17564`: FIX: correctly handle large arcs
* :ghpull:`17641`: Qt backports
* :ghpull:`17640`: More qt fractional DPI fixes
* :ghpull:`17638`: V3.2.1 doc
* :ghpull:`15656`: Support fractional HiDpi scaling with Qt backends
* :ghpull:`17600`: FIX: work with PyQt 5.15
* :ghpull:`17598`: DOC: remove banner
* :ghpull:`17618`: Doc event loop
* :ghpull:`17614`: DOC: Remove duplicated line.
* :ghpull:`17611`: Backport #17606 to v3.2.x
* :ghpull:`17609`: Backport PR #17602: FIX: propagate _is_saving state when changing can…
* :ghpull:`17606`: Move codecov.yml to .github.
* :ghpull:`17602`: FIX: propagate _is_saving state when changing canvases
* :ghpull:`17605`: Backport PR #17560: FIX: do not let no-op monkey patches to renderer …
* :ghpull:`17601`: Backport PR #16948 on branch v3.2.x (solution: All subclasses of LocationEvent could be used in cbook.callbacks before being fully initialized - issue 15139)
* :ghpull:`17560`: FIX: do not let no-op monkey patches to renderer leak out
* :ghpull:`16948`: solution: All subclasses of LocationEvent could be used in cbook.callbacks before being fully initialized - issue 15139
* :ghpull:`17588`: Backport PR #17565: FIX: support Qt 5.15
* :ghpull:`17593`: Backport PR #17587 on branch v3.2.x (Add a docstring to toolkit's BezierPath.__init__.)
* :ghpull:`17587`: Add a docstring to toolkit's BezierPath.__init__.
* :ghpull:`17565`: FIX: support Qt 5.15
* :ghpull:`17562`: Backport PR #17470 on branch v3.2.x (FIX: add guardrails for too big tk figures)
* :ghpull:`17470`: FIX: add guardrails for too big tk figures
* :ghpull:`17553`: Backport PR #17552 on branch v3.2.x (ci: Add xcb libraries that were removed from PyQt5.)
* :ghpull:`17552`: ci: Add xcb libraries that were removed from PyQt5.
* :ghpull:`17533`: Backport PR #17408 on branch v3.2.x
* :ghpull:`17408`: FIX: cancel pending autoscale on manually setting limits
* :ghpull:`17501`: Backport PR #17499: Fix scatter singlecolor
* :ghpull:`17499`: Fix scatter singlecolor
* :ghpull:`17468`: v3.2.x: Fix leaks in C++ code
* :ghpull:`17457`: Backport PR #17391 on branch v3.2.x
* :ghpull:`17391`: tk/wx: Fix saving after the window is closed
* :ghpull:`17435`: Backport PR #17422: Unstale viewlims before draw()ing polar axes.
* :ghpull:`17422`: Unstale viewlims before draw()ing polar axes.
* :ghpull:`17407`: FIX: don't try to use non-standard functions on standard status bars
* :ghpull:`17346`: Backport #17084 and #17210 to v3.2.x
* :ghpull:`17084`: Fix macosx segfault
* :ghpull:`17300`: Backport PR #17263 on branch v3.2.x (you can't call CGDataProviderCreateWithData on a stack pointer)
* :ghpull:`17263`: you can't call CGDataProviderCreateWithData on a stack pointer
* :ghpull:`17272`: Backport PR #17271 on branch v3.2.x (MNT: do not try to import xml.etree.cElementTree)
* :ghpull:`17271`: MNT: do not try to import xml.etree.cElementTree
* :ghpull:`17268`: Backport PR #17261 on branch v3.2.x (avoid calling wx.Bitmap() if width or height is zero)
* :ghpull:`17261`: avoid calling wx.Bitmap() if width or height is zero
* :ghpull:`17257`: Backport eps work
* :ghpull:`17255`: Fix eps + usetex combo.
* :ghpull:`17254`: Backport PR #17252 on branch v3.2.x (Fix bug where matplotlib.style('default') resets the backend)
* :ghpull:`17252`: Fix bug where matplotlib.style('default') resets the backend
* :ghpull:`17250`: Merge pull request #17206 from jklymak/fix-bypass-inverse-collection
* :ghpull:`17206`: FIX: bypass inverse in collection
* :ghpull:`17241`: Backport PR #17240 on branch v3.2.x (CI: Download wx wheels for the correct Ubuntu version.)
* :ghpull:`17240`: CI: Download wx wheels for the correct Ubuntu version.
* :ghpull:`17210`: Fix missing attribute in _SVGConverter.
* :ghpull:`17186`: Backport PR #17131 on branch v3.2.x
* :ghpull:`17188`: Backport PR #16958: MAINT: Replace uses of tostring with tobytes
* :ghpull:`17187`: Backport PR #17076: Fix SyntaxErrors when running setup in old Python
* :ghpull:`16913`: Fix use of psfrags in ps backend + usetex.
* :ghpull:`16476`: Fix baseline alignment when using usetex.
* :ghpull:`17131`: BUG: Fix formatting error in GridSpec.__repr__
* :ghpull:`17132`: Backport PR #17126 on branch v3.2.x (Remove Python2/3 info box)
* :ghpull:`17126`: Remove Python2/3 info box
* :ghpull:`17076`: Fix SyntaxErrors when running setup in old Python
* :ghpull:`17071`: Backport PR #17065 on branch v3.2.x (Fix macOS CI test failure)
* :ghpull:`17065`: Fix macOS CI test failure
* :ghpull:`17051`: Backport PR #17045: Fix missing-references.json.
* :ghpull:`17045`: Fix missing-references.json.
* :ghpull:`17020`: Merge pull request #17017 from jklymak/fix-blended-transform
* :ghpull:`17017`: FIX: force blended transforms with data to be in data space
* :ghpull:`16989`: Backport PR #16980 on branch v3.2.x (Correctly disable more drawing methods in tight_bboxing renderer.)
* :ghpull:`16980`: Correctly disable more drawing methods in tight_bboxing renderer.
* :ghpull:`16974`: Backport PR #16940 on branch v3.2.x (DOC/FIX: clarify the docs for check_figures_equal)
* :ghpull:`16979`: Backport PR #16970 on branch v3.2.x (tk: Don't resize toolbar during resize event.)
* :ghpull:`16970`: tk: Don't resize toolbar during resize event.
* :ghpull:`16940`: DOC/FIX: clarify the docs for check_figures_equal
* :ghpull:`16969`: Backport PR #16966 on branch v3.2.x (Fix animation writer fallback.)
* :ghpull:`16966`: Fix animation writer fallback.
* :ghpull:`16958`: MAINT: Replace uses of tostring with tobytes
* :ghpull:`16950`: Backport PR #16949 on branch v3.2.x (TST: Don't modify actual pyplot file for boilerplate test.)
* :ghpull:`16949`: TST: Don't modify actual pyplot file for boilerplate test.
* :ghpull:`16932`: Backport PR #16929 on branch v3.2.x (tk: Resize the canvas, not the figure.)
* :ghpull:`16929`: tk: Resize the canvas, not the figure.
* :ghpull:`16880`: Backport PR #16870: Unbreak CI by xfailing wxAgg test on macOS
* :ghpull:`16870`: Unbreak CI by xfailing wxAgg test on macOS
* :ghpull:`16869`: Backport PR #16867 on branch v3.2.x (BLD: Auto-trigger macOS/Linux wheels on tags.)
* :ghpull:`16867`: BLD: Auto-trigger macOS/Linux wheels on tags.
* :ghpull:`16852`: Backport PR #16851 on branch v3.2.x (DOC: Fix docstring of Axes.secondary_yaxis.)
* :ghpull:`16855`: Fix typo in deprecation warning
* :ghpull:`16851`: DOC: Fix docstring of Axes.secondary_yaxis.
* :ghpull:`16842`: Backport PR #16835 on branch v3.2.x (Don't forget to export isdeleted on Qt4.)
* :ghpull:`16835`: Don't forget to export isdeleted on Qt4.
* :ghpull:`15695`: Define \mathdefault as a noop in the usetex preamble.
* :ghpull:`14694`: Vectorize Arc.draw.

Issues (34):

* :ghissue:`17547`: Arcs with large radii in small
* :ghissue:`17440`: Low quality window plots on hidpi display
* :ghissue:`17104`: input() caused _tkinter.TclError: invalid command name XXX after plot.close()
* :ghissue:`17613`: Matplotlib.pdf duplication
* :ghissue:`15139`: All subclasses of LocationEvent could be used in cbook.callbacks before being fully initialized
* :ghissue:`17004`: Output regression in 3.2 that affects SymPy's plotting
* :ghissue:`17599`: Saving issue with pdf backend
* :ghissue:`17542`: Matplotlib 3.2.1 savefig empty image when fig size matches data size exactly
* :ghissue:`17594`: Cannot use Qt4Agg backend in mpl 3.2.1
* :ghissue:`17460`: set_size_inches with a width over 14090 crashes Xorg
* :ghissue:`17331`: Surprising/changed axis limit (autoscale) behavior
* :ghissue:`17423`: Scatter produce multiple colors for a single RGB/RGBA input
* :ghissue:`17385`: Matplotlib memory leaks when save figure in a file with qt5 backend
* :ghissue:`15474`: Memory leak with log scale in pcolorfast, pcolormesh, imshow ...
* :ghissue:`17388`: savefig error: tkinter.TclError: invalid command name "."
* :ghissue:`16909`: plot save and plot show
* :ghissue:`17085`: set_function not working properly in backend_wx
* :ghissue:`17418`: Issue rendering polar plot (agg backend?) with rorigin set
* :ghissue:`17061`: Segmentation fault with macosx backend
* :ghissue:`17253`: EPS + usetex is broken
* :ghissue:`16700`: Deprecation warnings from stylelib
* :ghissue:`17203`: Subplots using bad axis limits in 3.2
* :ghissue:`16898`: EPS and ``usetex`` give blank output
* :ghissue:`16409`: Confusing error on fully commented-out usetex strings
* :ghissue:`17075`: Installation error downloading jquery on python3 on Ubuntu
* :ghissue:`17037`: Travis Failing in many PRs
* :ghissue:`17033`: Using a ``TextBox`` in current master produces a seemingly unrelated warning.
* :ghissue:`17016`: Issues with autoscaling and transforms with 3.2+
* :ghissue:`16978`: savefig("myplot.svgz", bbox_inches="tight") fails
* :ghissue:`16965`: FuncAnimation.save throws TypeError
* :ghissue:`16916`: check_figures_equal regression from 3.2.0 to 3.2.1
* :ghissue:`10566`: blocking UI functions cause figure size to change
* :ghissue:`10083`: Wrong figure height after set_size_inches within event handler
* :ghissue:`16834`: Error importing FigureCanvas
